@@ -134,7 +134,8 @@ Device          Start        End    Sectors   Size Type
         self.assertEqual(part_result, result)
         execute_calls = [
             mock.call('fdisk', '-l', self.dev, run_as_root=True),
-            mock.call('lsblk', '-PbioUUID', partition_id,
+            mock.call('lsblk', partition_id, '--pairs', '--bytes', '--ascii',
+                      '--output', 'UUID', use_standard_locale=True,
                       run_as_root=True)
         ]
         mock_execute.assert_has_calls(execute_calls)
@@ -161,7 +162,9 @@ Device     Boot Start       End   Sectors Size Id Type
                           disk_utils.get_uefi_disk_identifier, self.dev)
         execute_calls = [
             mock.call('fdisk', '-l', self.dev, run_as_root=True),
-            mock.call('lsblk', '-PbioUUID', partition_id, run_as_root=True)
+            mock.call('lsblk', partition_id, '--pairs', '--bytes', '--ascii',
+                      '--output', 'UUID', use_standard_locale=True,
+                      run_as_root=True)
         ]
         mock_execute.assert_has_calls(execute_calls)
 
@@ -565,7 +568,8 @@ class PopulateImageTestCase(base.IronicLibTestCase):
         type(mock_qinfo.return_value).file_format = mock.PropertyMock(
             return_value='qcow2')
         disk_utils.populate_image('src', 'dst')
-        mock_cg.assert_called_once_with('src', 'dst', 'raw', True)
+        mock_cg.assert_called_once_with('src', 'dst', 'raw', True,
+                                        sparse_size='0')
         self.assertFalse(mock_dd.called)
 
 
@@ -635,11 +639,12 @@ class OtherFunctionTestCase(base.IronicLibTestCase):
     @mock.patch.object(utils, 'execute', autospec=True)
     def test_convert_image_flags(self, execute_mock):
         disk_utils.convert_image('source', 'dest', 'out_format',
-                                 cache='directsync', out_of_order=True)
+                                 cache='directsync', out_of_order=True,
+                                 sparse_size='0')
         execute_mock.assert_called_once_with(
             'qemu-img', 'convert', '-O',
             'out_format', '-t', 'directsync',
-            '-W', 'source', 'dest',
+            '-S', '0', '-W', 'source', 'dest',
             run_as_root=False,
             prlimit=mock.ANY,
             use_standard_locale=True,
@@ -898,8 +903,8 @@ BLKID_PROBE = ("""
                """PTUUID="123456" PTTYPE="gpt"
                """)
 
-BLKID_NORMAL = (
-    'dev/nvme0n1p1: UUID="123" BLOCK_SIZE="512" TYPE="vfat" '
+LSBLK_NORMAL = (
+    'UUID="123" BLOCK_SIZE="512" TYPE="vfat" '
     'PARTLABEL="EFI System Partition" PARTUUID="123456"'
 )
 
@@ -908,27 +913,27 @@ BLKID_NORMAL = (
 class GetDeviceInformationTestCase(base.IronicLibTestCase):
 
     def test_normal(self, mock_execute):
-        mock_execute.return_value = BLKID_NORMAL, ""
+        mock_execute.return_value = LSBLK_NORMAL, ""
         result = disk_utils.get_device_information('/dev/fake')
         self.assertEqual(
             {'UUID': '123', 'BLOCK_SIZE': '512', 'TYPE': 'vfat',
              'PARTLABEL': 'EFI System Partition', 'PARTUUID': '123456'},
             result
         )
-        mock_execute.assert_called_once_with('blkid', '/dev/fake',
-                                             use_standard_locale=True,
-                                             run_as_root=True)
+        mock_execute.assert_called_once_with(
+            'lsblk', '/dev/fake', '--pairs', '--bytes', '--ascii', '--nodeps',
+            '--output-all', use_standard_locale=True, run_as_root=True)
 
     def test_probe(self, mock_execute):
         mock_execute.return_value = BLKID_PROBE, ""
         result = disk_utils.get_device_information('/dev/fake', probe=True)
         self.assertEqual({'PTUUID': '123456', 'PTTYPE': 'gpt'}, result)
-        mock_execute.assert_called_once_with('blkid', '/dev/fake', '--probe',
+        mock_execute.assert_called_once_with('blkid', '/dev/fake', '-p',
                                              use_standard_locale=True,
                                              run_as_root=True)
 
     def test_fields(self, mock_execute):
-        mock_execute.return_value = BLKID_NORMAL, ""
+        mock_execute.return_value = LSBLK_NORMAL, ""
         result = disk_utils.get_device_information('/dev/fake',
                                                    fields=['UUID', 'LABEL'])
         # No filtering on our side, so returning all fake fields
@@ -937,33 +942,44 @@ class GetDeviceInformationTestCase(base.IronicLibTestCase):
              'PARTLABEL': 'EFI System Partition', 'PARTUUID': '123456'},
             result
         )
-        mock_execute.assert_called_once_with('blkid', '/dev/fake',
-                                             '--match-tag', 'UUID',
-                                             '--match-tag', 'LABEL',
-                                             use_standard_locale=True,
-                                             run_as_root=True)
+        mock_execute.assert_called_once_with(
+            'lsblk', '/dev/fake', '--pairs', '--bytes', '--ascii', '--nodeps',
+            '--output', 'UUID,LABEL',
+            use_standard_locale=True, run_as_root=True)
 
     def test_empty(self, mock_execute):
         mock_execute.return_value = "\n", ""
-        result = disk_utils.get_device_information('/dev/fake')
+        result = disk_utils.get_device_information('/dev/fake', probe=True)
         self.assertEqual({}, result)
         mock_execute.assert_called_once_with('blkid', '/dev/fake',
-                                             use_standard_locale=True,
+                                             '-p', use_standard_locale=True,
                                              run_as_root=True)
 
 
-@mock.patch.object(disk_utils, 'get_device_information', autospec=True)
+@mock.patch.object(utils, 'execute', autospec=True)
 class GetPartitionTableTypeTestCase(base.IronicLibTestCase):
-    def test_ok(self, mock_get_device_info):
-        mock_get_device_info.return_value = {'PTTYPE': 'gpt'}
-        self.assertEqual('gpt',
-                         disk_utils.get_partition_table_type('/dev/fake'))
-        mock_get_device_info.assert_called_once_with('/dev/fake', probe=True)
+    def test_gpt(self, mocked_execute):
+        self._test_by_type(mocked_execute, 'gpt', 'gpt')
 
-    def test_missing(self, mock_get_device_info):
-        mock_get_device_info.return_value = {}
-        self.assertIsNone(disk_utils.get_partition_table_type('/dev/fake'))
-        mock_get_device_info.assert_called_once_with('/dev/fake', probe=True)
+    def test_msdos(self, mocked_execute):
+        self._test_by_type(mocked_execute, 'msdos', 'msdos')
+
+    def test_unknown(self, mocked_execute):
+        self._test_by_type(mocked_execute, 'whatever', 'unknown')
+
+    def _test_by_type(self, mocked_execute, table_type_output,
+                      expected_table_type):
+        parted_ret = PARTED_OUTPUT_UNFORMATTED.format(table_type_output)
+
+        mocked_execute.side_effect = [
+            (parted_ret, None),
+        ]
+
+        ret = disk_utils.get_partition_table_type('hello')
+        mocked_execute.assert_called_once_with(
+            'parted', '--script', 'hello', '--', 'print',
+            run_as_root=True, use_standard_locale=True)
+        self.assertEqual(expected_table_type, ret)
 
 
 PARTED_OUTPUT_UNFORMATTED = '''Model: whatever
